pub struct Event {
pub event_code: String,
pub event_time: String,
pub location: Option<Box<Location>>,
}Expand description
Event : An event of a shipment
Fields
event_code: StringThe event code of a shipment, such as Departed, Received, and ReadyForReceive.
event_time: StringThe date and time of an event for a shipment.
location: Option<Box<Location>>Implementations